@@ -295,6 +295,11 @@ class BasePulsar(object):
         """Return sun position vector at all timestamps"""
         return self._sunssb[self._isort, :]
 
+    @property
+    def telescope(self):
+        """Return telescope vector at all timestamps"""
+        return self._telescope[self._isort]
+
 
 class PintPulsar(BasePulsar):
     def __init__(self, toas, model, sort=True, drop_pintpsr=True, planets=True):
@@ -316,6 +321,7 @@ class PintPulsar(BasePulsar):
         self._toaerrs = np.array(toas.get_errors().to(u.s), dtype="float64")
         self._designmatrix = model.designmatrix(toas)[0]
         self._ssbfreqs = np.array(model.barycentric_radio_freq(toas), dtype="float64")
+        self._telescope = np.array(toas.get_obss())
 
         # fitted parameters
         self.fitpars = ["Offset"] + [par for par in model.params if not getattr(model, par).frozen]
@@ -361,14 +367,14 @@ class PintPulsar(BasePulsar):
         pars = [par for par in model.params if not getattr(model, par).frozen]
 
         if hasattr(model, "DM"):
-            self._dm = model["DM"].value
+            self._dm = float(model["DM"].value)
 
         dmx = {
             par: {
-                "DMX": model[par].value,
-                "DMXerr": model[par].uncertainty_value,
-                "DMXR1": model[par[:3] + "R1" + par[3:]].value,
-                "DMXR2": model[par[:3] + "R2" + par[3:]].value,
+                "DMX": float(model[par].value),
+                "DMXerr": float(model[par].uncertainty_value),
+                "DMXR1": float(model[par[:3] + "R1" + par[3:]].value),
+                "DMXR2": float(model[par[:3] + "R2" + par[3:]].value),
                 "fit": par in pars,
             }
             for par in pars
@@ -447,6 +453,7 @@ class Tempo2Pulsar(BasePulsar):
         self._toaerrs = np.double(t2pulsar.toaerrs) * 1e-6
         self._designmatrix = np.double(t2pulsar.designmatrix())
         self._ssbfreqs = np.double(t2pulsar.ssbfreqs()) / 1e6
+        self._telescope = np.char.decode(t2pulsar.telescope(), encoding="ascii")
 
         # fitted parameters
         self.fitpars = ["Offset"] + [str(p) for p in t2pulsar.pars()]
@@ -487,14 +494,14 @@ class Tempo2Pulsar(BasePulsar):
         pars = t2pulsar.pars(which="set")
 
         if "DM" in pars:
-            self._dm = t2pulsar["DM"].val
+            self._dm = float(t2pulsar["DM"].val)
 
         dmx = {
             par: {
-                "DMX": t2pulsar[par].val,
-                "DMXerr": t2pulsar[par].err,
-                "DMXR1": t2pulsar[par[:3] + "R1" + par[3:]].val,
-                "DMXR2": t2pulsar[par[:3] + "R2" + par[3:]].val,
+                "DMX": float(t2pulsar[par].val),
+                "DMXerr": float(t2pulsar[par].err),
+                "DMXR1": float(t2pulsar[par[:3] + "R1" + par[3:]].val),
+                "DMXR2": float(t2pulsar[par[:3] + "R2" + par[3:]].val),
                 "fit": par in pars,
             }
             for par in pars
