@@ -31,7 +31,98 @@ from enterprise.signals.parameter import function
 logger = logging.getLogger(__name__)
 
 
-def get_coefficients(pta, params, n=1, phiinv_method="cliques", common_sparse=False):
+class ConditionalGP:
+    def __init__(self, pta, phiinv_method="cliques"):
+        """This class allows the computation of conditional means and
+        random draws for all GP coefficients/realizations in a model,
+        given a vector of hyperparameters. It currently requires combine=False
+        for all GPs (or otherwise distinct bases) and does not
+        work with MarginalizingTimingModel (fast new-style likelihood)."""
+
+        self.pta = pta
+        self.phiinv_method = phiinv_method
+
+    def _make_conditional(self, params):
+        TNrs = self.pta.get_TNr(params)
+        TNTs = self.pta.get_TNT(params)
+        phiinvs = self.pta.get_phiinv(params, logdet=False, method=self.phiinv_method)
+
+        # TO DO: all this could be more efficient
+        #        also it's unclear if it works with MarginalizingTimingModel
+        if self.pta._commonsignals:
+            TNr = np.concatenate(TNrs)
+            Sigma = sps.block_diag(TNTs, "csc") + sps.csc_matrix(phiinvs)
+
+            ch = cholesky(Sigma)
+            mn = ch(TNr)
+            chL = ch.L()
+            # Li = sps.linalg.inv(ch.L()).toarray()
+
+            return mn, chL
+        else:
+            mns, chLs = [], []
+            for TNr, TNT, phiinv in zip(TNrs, TNTs, phiinvs):
+                Sigma = TNT + (np.diag(phiinv) if phiinv.ndim == 1 else phiinv)
+
+                ch = sl.cho_factor(Sigma, lower=True)
+                mns.append(sl.cho_solve(ch, TNr))
+                chLs.append(np.tril(ch[0]))
+                # Lis.append(sl.inv(np.tril(ch[0])))
+
+            return mns, chLs
+
+    def _sample_conditional(self, params, n=1, gp=False, variance=True):
+        mn, chL = self._make_conditional(params)
+
+        ret = []
+        for j in range(n):
+            # since Sigma = L L^T, Sigma^-1 = L^-T L^-1
+            # and L^-T x has variance L^-T L^-1 for normal x
+            if self.pta._commonsignals:
+                # b = mn + np.dot(np.random.randn(Li.shape[0]), Li)
+                b = mn + (sps.linalg.spsolve_triangular(chL.T, lower=False) if variance else 0)
+            else:
+                b = np.concatenate(mn)
+                if variance:
+                    b = b + np.concatenate(
+                        [sl.solve_triangular(c.T, np.random.randn(c.shape[0]), lower=False) for c in chL]
+                    )
+
+            pardict, ntot = {}, 0
+            for i, model in enumerate(self.pta.pulsarmodels):
+                for sig in model._signals:
+                    if sig.signal_type in ["basis", "common basis"]:
+                        sb = sig.get_basis(params=params)
+                        nb = sb.shape[1]
+
+                        if nb + ntot > len(b):
+                            raise IndexError("Missing parameters! You need to set combine=False in your GPs.")
+
+                        if gp:
+                            pardict[sig.name] = np.dot(sb, b[ntot : nb + ntot])
+                        else:
+                            pardict[sig.name + "_coefficients"] = b[ntot : nb + ntot]
+
+                        ntot += nb
+
+            ret.append(pardict)
+
+        return ret
+
+    def get_mean_coefficients(self, params):
+        return self._sample_conditional(params, n=1, gp=False, variance=False)[0]
+
+    def sample_coefficients(self, params, n=1):
+        return self._sample_conditional(params, n, gp=False, variance=True)
+
+    def get_mean_processes(self, params):
+        return self._sample_conditional(params, n=1, gp=True, variance=False)[0]
+
+    def sample_processes(self, params, n=1):
+        return self._sample_conditional(params, n, gp=True, variance=True)
+
+
+def get_coefficients(pta, params, n=1, phiinv_method="cliques", variance=True, common_sparse=False):
     ret = []
 
     TNrs = pta.get_TNr(params)
@@ -46,7 +137,7 @@ def get_coefficients(pta, params, n=1, phiinv_method="cliques", common_sparse=Fa
 
             ch = cholesky(Sigma)
             mn = ch(TNr)
-            Li = sps.linalg.inv(ch.L()).toarray()
+            Li = sps.linalg.inv(ch.L()).toarray().T
         else:
             Sigma = sl.block_diag(*TNTs) + phiinvs
             TNr = np.concatenate(TNrs)
@@ -56,7 +147,7 @@ def get_coefficients(pta, params, n=1, phiinv_method="cliques", common_sparse=Fa
             Li = u * np.sqrt(1 / s)
 
         for j in range(n):
-            b = mn + np.dot(Li, np.random.randn(Li.shape[0]))
+            b = mn + (np.dot(Li, np.random.randn(Li.shape[0])) if variance else 0)
 
             pardict, ntot = {}, 0
             for i, model in enumerate(pta.pulsarmodels):
@@ -96,7 +187,7 @@ def get_coefficients(pta, params, n=1, phiinv_method="cliques", common_sparse=Fa
                 Li = u * np.sqrt(1 / s)
 
             for j in range(n):
-                b = mn + np.dot(Li, np.random.randn(Li.shape[0]))
+                b = mn + (np.dot(Li, np.random.randn(Li.shape[0])) if variance else 0)
 
                 pardict, ntot = {}, 0
                 for sig in model._signals:
